@@ -1,7 +1,7 @@
-from . import Kidney
-from . import Monochromator
-from . import Sample
-from .virtualMACS import virtualMACS
+from .kidney import Kidney
+from .monochromator import Monochromator
+from .samplse import Sample
+from . import virtualMACS
 from .scripting import get_kidney_params
 from .scripting import get_mono_params
 from .scripting import generate_MACS_parts
